@@ -32,13 +32,19 @@ def register_module(module, container):
         logging.warning("Module found that is missing a register function")
 
 
-def load_and_register_modules(path_pattern, container):
+def load_and_register_modules(path_pattern, container, base_directory="."):
+    current_directory = os.getcwd()
+
+    os.chdir(base_directory)
+    
     module_paths = get_module_paths(path_pattern)
     modules = load_modules(module_paths)
 
     for module in modules:
         register_module(module, container)
 
+    os.chdir(current_directory)
+
     return container
 
 
